==> fsd-0.0.29.tar.gz: fsd-0.0.29/fsd/dependency/DependencyCheckAgent.py <==
import os
import aiohttp
import asyncio
import json
import sys

sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
from util.portkey import AIGateway
from json_repair import repair_json
from log.logger_config import get_logger
logger = get_logger(__name__)

class DependencyCheckAgent:
    def __init__(self, repo):
        self.repo = repo
        self.max_tokens = 4096
        self.ai = AIGateway()

    def read_file_content(self, file_path):
        """
        Read and return the content of any type of file, including special files like Podfile.

        Args:
            file_path (str): Path to the file.

        Returns:
            str: Content of the file or empty string if file doesn't exist.
        """
        if not os.path.exists(file_path):
            logger.info(f"\n ### The `DependencyCheckAgent` has detected that the file does not exist: `{file_path}`")
            return ""

        encodings = ['utf-8', 'iso-8859-1', 'ascii', 'utf-16']

        for encoding in encodings:
            try:
                with open(file_path, "r", encoding=encoding) as file:
                    return file.read()
            except UnicodeDecodeError:
                continue
            except Exception as e:
                logger.info(f"\n ### The `DependencyCheckAgent` encountered an error while reading `{file_path}` with `{encoding}` encoding: `{e}`")

        # If all text encodings fail, try reading as binary
        try:
            with open(file_path, "rb") as file:
                return file.read().decode('utf-8', errors='replace')
        except Exception as e:
            logger.info(f"\n ### The `DependencyCheckAgent` failed to read `{file_path}` in binary mode: `{e}`")

        return ""

    async def get_dependency_check_plan(self, user_prompt):
        """
        Get a development plan for all txt files from Azure OpenAI based on the user prompt.

        Args:
            session (aiohttp.ClientSession): The aiohttp session to use for the request.
            all_file_contents (str): The concatenated contents of all files.
            user_prompt (str): The user's prompt.

        Returns:
            dict: Development plan or error reason.
        """
        messages = [
            {
                "role": "system",
                "content": (
                    "Check if the user mentions needing to install any dependencies through CLI tools like npm, pod, pip, pnpm, or similar package managers. Return '0' if no CLI-based dependency installations are mentioned or if it's just code configuration. Return '1' only if CLI-based dependency installations are explicitly mentioned. Respond in this exact JSON format:\n"
                    "{\n"
                    '    "result": "0" or "1"\n'
                    "}"
                )
            },
            {
                "role": "user",
                "content": user_prompt
            }
        ]

        try:
            logger.info("\n ### The `DependencyCheckAgent` is initiating a request to the AI Gateway")
            response = await self.ai.prompt(messages, self.max_tokens, 0.2, 0.1)
            res = json.loads(response.choices[0].message.content)
            logger.info("\n ### The `DependencyCheckAgent` has successfully parsed the AI response")
            return res
        except json.JSONDecodeError:
            logger.info("\n ### The `DependencyCheckAgent` encountered a JSON decoding error and is attempting to repair it")
            good_json_string = repair_json(response.choices[0].message.content)
            plan_json = json.loads(good_json_string)
            logger.info("\n ### The `DependencyCheckAgent` has successfully repaired and parsed the JSON")
            return plan_json
        except Exception as e:
            logger.info(f"\n ### The `DependencyCheckAgent` encountered an error during the process: `{e}`")
            return {
                "reason": str(e)
            }

    async def get_dependency_check_plans(self, user_prompt):
        """
        Get development plans for a list of txt files from Azure OpenAI based on the user prompt.

        Args:
            files (list): List of file paths.
            user_prompt (str): The user's prompt.

        Returns:
            dict: Development plan or error reason.
        """
        logger.info("\n ### The `DependencyCheckAgent` is beginning to retrieve dependency check plans")
        plan = await self.get_dependency_check_plan(user_prompt)
        logger.info("\n ### The `DependencyCheckAgent` has successfully retrieved dependency check plans")
        return plan

==> fsd-0.0.35.tar.gz: fsd-0.0.35/fsd/dependency/DependencyCheckAgent.py <==
import os
import aiohttp
import asyncio
import json
import sys

sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
from util.portkey import AIGateway
from json_repair import repair_json
from log.logger_config import get_logger
logger = get_logger(__name__)

class DependencyCheckAgent:
    def __init__(self, repo):
        self.repo = repo
        self.max_tokens = 4096
        self.ai = AIGateway()

    def read_file_content(self, file_path):
        """
        Read and return the content of any type of file, including special files like Podfile.

        Args:
            file_path (str): Path to the file.

        Returns:
            str: Content of the file or empty string if file doesn't exist.
        """
        if not os.path.exists(file_path):
            logger.debug(f"\n ### The `DependencyCheckAgent` has detected that the file does not exist: `{file_path}`")
            return ""

        encodings = ['utf-8', 'iso-8859-1', 'ascii', 'utf-16']

        for encoding in encodings:
            try:
                with open(file_path, "r", encoding=encoding) as file:
                    return file.read()
            except UnicodeDecodeError:
                continue
            except Exception as e:
                logger.debug(f"\n ### The `DependencyCheckAgent` encountered an error while reading `{file_path}` with `{encoding}` encoding: `{e}`")

        # If all text encodings fail, try reading as binary
        try:
            with open(file_path, "rb") as file:
                return file.read().decode('utf-8', errors='replace')
        except Exception as e:
            logger.debug(f"\n ### The `DependencyCheckAgent` failed to read `{file_path}` in binary mode: `{e}`")

        return ""

    async def get_dependency_check_plan(self, user_prompt):
        """
        Get a development plan for all txt files from Azure OpenAI based on the user prompt.

        Args:
            session (aiohttp.ClientSession): The aiohttp session to use for the request.
            all_file_contents (str): The concatenated contents of all files.
            user_prompt (str): The user's prompt.

        Returns:
            dict: Development plan or error reason.
        """
        messages = [
            {
                "role": "system",
                "content": (
                    "Check if the user mentions needing to install any dependencies through CLI tools like npm, pod, pip, pnpm, or similar package managers. Return '0' if no CLI-based dependency installations are mentioned or if it's just code configuration. Return '1' only if CLI-based dependency installations are explicitly mentioned. Respond in this exact JSON format:\n"
                    "{\n"
                    '    "result": "0" or "1"\n'
                    "}"
                )
            },
            {
                "role": "user",
                "content": user_prompt
            }
        ]

        try:
            logger.debug("\n ### The `DependencyCheckAgent` is initiating a request to the AI Gateway")
            response = await self.ai.prompt(messages, self.max_tokens, 0.2, 0.1)
            res = json.loads(response.choices[0].message.content)
            logger.debug("\n ### The `DependencyCheckAgent` has successfully parsed the AI response")
            return res
        except json.JSONDecodeError:
            logger.debug("\n ### The `DependencyCheckAgent` encountered a JSON decoding error and is attempting to repair it")
            good_json_string = repair_json(response.choices[0].message.content)
            plan_json = json.loads(good_json_string)
            logger.debug("\n ### The `DependencyCheckAgent` has successfully repaired and parsed the JSON")
            return plan_json
        except Exception as e:
            logger.debug(f"\n ### The `DependencyCheckAgent` encountered an error during the process: `{e}`")
            return {
                "reason": str(e)
            }

    async def get_dependency_check_plans(self, user_prompt):
        """
        Get development plans for a list of txt files from Azure OpenAI based on the user prompt.

        Args:
            files (list): List of file paths.
            user_prompt (str): The user's prompt.

        Returns:
            dict: Development plan or error reason.
        """
        logger.debug("\n ### The `DependencyCheckAgent` is beginning to retrieve dependency check plans")
        plan = await self.get_dependency_check_plan(user_prompt)
        logger.debug("\n ### The `DependencyCheckAgent` has successfully retrieved dependency check plans")
        return plan
